<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">
<head>
  <title>Outage contact information :: TOPP Outage Escalation Tool</title>
  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
  <meta http-equiv="Content-Language" content="en-us" />
  <link type="text/css" rel="stylesheet" href="/css/tripoli.base.css" />
  <!--[if IE]><link rel="stylesheet" type="text/css" href="/css/tripoli.base.ie.css"><![endif]-->
  <link type="text/css" rel="stylesheet" href="/css/whatsup.css" />
</head>
<body>
  <xi:include href="site.html" />
  <div class="content">
    <h1>TOPP Outage Contact Information</h1>
    <table id="contact-list">
      <thead>
        <tr>
          <th>Name</th>
          <th>Email</th>
          <th>Phone</th>
        </tr>
      </thead>
      <tbody>
        <tr py:for="index, name in enumerate(sorted(contacts))" py:with="contact = contacts[name]" class="${index%2 and 'odd' or 'even'}">
          <td><a href="${contact.get('url', '/contact/' + name)}">${name}</a></td>
          <td>
            <ul class="contact-emails" py:if="contact['email']">
              <li py:for="index, email in enumerate(contact['email'])"
                  py:attrs="{'class': index == 0 and 'primary' or None}">
                <a href="mailto:${email}">${email}</a>
              </li>
            </ul>
          </td>
          <td>${contact.get('phone', '')}</td>
        </tr>
      </tbody>
    </table>
  </div>
</body>
</html>
