<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">
<head>
  <title>${name}</title>
  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
  <meta http-equiv="Content-Language" content="en-us" />
  <link type="text/css" rel="stylesheet" href="/css/tripoli.base.css" />
  <!--[if IE]><link rel="stylesheet" type="text/css" href="/css/tripoli.base.ie.css"><![endif]-->
  <link type="text/css" rel="stylesheet" href="/css/whatsup.css" />
</head>
<body py:with="contact = contacts[name]">
  <xi:include href="site.html" />
  <div class="content">
    <h1>${name}</h1>
    <dl>
      <py:for each="item in ('email', 'phone')">
        <py:if test="contact.get(item)">
          <dt>${item.title()}</dt>
          <dd py:with="items = contact[item]">
            <ul>
              <li py:for="index, i in enumerate(items)"
                  py:attrs="{'class': index == 0 and 'primary' or None}">
                <a href="mailto:${i}" py:strip="item not in ['email']"><span py:strip="item in ['email']">${i}</span></a>
              </li>
            </ul>
          </dd>
        </py:if>
      </py:for>
      <py:if test="contact.get('aim')">
        <dt>AIM</dt>
        <dd>
          <a href="aim:goim?screenname=${contact['aim']}">
            ${contact['aim']}
          </a>
        </dd>
      </py:if>
    </dl>

    <div py:if="contact.get('contact') and contact['contact'] not in contact">
      ${contact['contact']}
    </div>
  </div>
</body>
</html>
