<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">
<head>
  <title>Report Fix :: TOPP Outage Escalation Tool</title>
  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
  <meta http-equiv="Content-Language" content="en-us" />
  <link type="text/css" rel="stylesheet" href="/css/tripoli.base.css" />
  <!--[if IE]><link rel="stylesheet" type="text/css" href="/css/tripoli.base.ie.css"><![endif]-->
  <link type="text/css" rel="stylesheet" href="/css/whatsup.css" />
</head>
<body>
  <xi:include href="site.html" />
  <div class="content">
    <h1>Report a Fix</h1>
    <form method="post">
      <ul>
        <li class="selfclear"><label for="site">Site:</label> 
          ${site}
          <input type="hidden" name="site" value="${site}" />
        </li>
        <li><label for="fix">Description:</label>
          <textarea id="fix" name="fix"></textarea>
        </li> 
        <li><label for="email">Your email:</label><input id="email" name="email" type="text" /></li>
      </ul>
      <input type="submit" name="submit" value="Submit"/>
    </form>
  </div>
</body>
</html>
