<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      py:strip="True">
  <ul id="topnav" class="selfclear">
    <li><a href="/">Sites</a></li>
    <li><a href="/contacts">Contacts</a></li>
  </ul>

  <div class="message" py:if="message">
    ${message}
  </div>

</html>
