.selfclear:after {
content: ".";
display: block;
height: 0;
clear: both;
visibility: hidden;
}

.selfclear {
display: inline-block; /* IE 7 */
}

.selfclear {
display: block;
}

* html .selfclear {
height: 1px; /* IE < 7 */
}

* html .pngfix {
zoom: 1;
behavior: expression((this.runtimeStyle.behavior="none")&&(this.pngSet?this.pngSet=true:(this.nodeName == "IMG" && this.src.toLowerCase().indexOf('.png')>-1 ? (this.runtimeStyle.backgroundImage = "none", this.runtimeStyle.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + this.src + "', sizingMethod='image')", this.src = "/img/transparent.gif") : (this.origBg = this.origBg ? this.origBg : this.currentStyle.backgroundImage.toString().replace('url("','').replace('")',''), this.runtimeStyle.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + this.origBg + "', sizingMethod='" + (this.currentStyle.backgroundRepeat=='no-repeat' ? 'crop' : 'scale') +"')", this.runtimeStyle.backgroundImage = "none")),this.pngSet=true));
}

body {
font-family: sans-serif;
padding: 0;
line-height: 1.6em;
}

a:link, 
a:visited {
color: #00a0cd; 
}

a:hover {
color: #ff5f0b;  
}

#topnav {
background: #333;
border-bottom: 2px solid #e5e5e5;
padding: 0 1em;
}

#topnav li {
float: left;
}

#topnav li a {
display: block;
padding: 0.5em 0.75em;
color: #ff5f0b;
text-decoration: none;
}

#topnav li a:hover {
text-decoration: underline;
color: #00a0cd;
}

.content {
padding: 1em;
}

.content h1 {
margin-top: 0;
}

table {
border-collapse: collapse;
}

thead th {
border-bottom: 1px solid #e5e5e5;
}

tbody th {
text-align: left;
width: 45%;
}

tbody tr.even {
background: #fcfcfc;
}

td {
padding: 10px;
border-bottom: 1px dotted #fafafa;
}

td .cool {
background: #5fb825; 
}

td .borked {
background: #d10404;
}

td .cool,
td .borked {
-moz-border-radius: 5px;
-webkit-border-radius: 5px;
border-radius: 5px;
padding: 5px;
color: #fff;
text-align: center;
}

td.site-description {
font-size: 0.9em;
color: #333;
}

table#status-list a {
display: block;
padding:  0.3em 0;
}

.content form ul,
.content form ul li {
list-style-type: none;
margin: 0 0 0.5em;
}

label {
float: left;
font-weight: bold;
width: 12em;
text-align: right;
padding: 0 0.75em 0 0;
}

ul.site-contacts,
ul.site-contacts li {
margin: 0;
padding: 0;
}

ul.site-contacts li {
list-style-type: none;
}

ul.contact-emails {
font-size: 0.9em;
color: #e5e5e5;
}

li.primary {
list-style-type: square;
font-size: 1.4em;
color: #5fb825;
}

li.primary span {
color: #000;
}

/* flash messages */
div.message {
background: gray;
color: orange;
font-size: 2em;
padding: 0.5em;
text-align: center;
}
