textarea{white-space:pre;}.content legend{margin-bottom:1.6em;}.content fieldset{padding-top:0;}sup,sub{font-size:100%;}.content legend:first-child{margin-top:0;}a abbr,a acronym{text-decoration:underline;}* html .content blockquote *{margin:.8em 0;}* html input{cursor:expression(this.type=='text' || this.type=='password' ? 'text' : 'pointer');display:expression(this.type=='hidden' ? 'none' : 'inline');}* html .content textarea,* html .content input,.content input[type='submit'],.content input[type='button']{padding:0;}